"use strict";
/**
 * @description Boot Scene
 * @author Digitsensitive <digit.sensitivee@gmail.com>
 * @copyright 2020 Digitsensitive
 * @license {@link https://opensource.org/licenses/MIT|MIT License}
 */
Object.defineProperty(exports, "__esModule", { value: true });
class BootScene extends Phaser.Scene {
    constructor() {
        super({
            key: 'BootScene'
        });
    }
    preload() {
        // set the background, create the loading and progress bar
        this.cameras.main.setBackgroundColor(0x000000);
        this.createLoadingGraphics();
        // pass value to change the loading bar fill
        this.load.on('progress', function (value) {
            this.progressBar.clear();
            this.progressBar.fillStyle(0x88e453, 1);
            this.progressBar.fillRect(this.cameras.main.width / 4, this.cameras.main.height / 2 - 16, (this.cameras.main.width / 2) * value, 16);
        }, this);
        // delete bar graphics, when loading complete
        this.load.on('complete', function () {
            this.progressBar.destroy();
            this.loadingBar.destroy();
        }, this);
        // load our package
        this.load.pack('preload', './assets/pack.json', 'preload');
    }
    update() {
        this.scene.start('MainScene');
    }
    createLoadingGraphics() {
        this.loadingBar = this.add.graphics();
        this.loadingBar.fillStyle(0xffffff, 1);
        this.loadingBar.fillRect(this.cameras.main.width / 4 - 2, this.cameras.main.height / 2 - 18, this.cameras.main.width / 2 + 4, 20);
        this.progressBar = this.add.graphics();
    }
}
exports.BootScene = BootScene;
