"use strict";
/**
 * @author       Digitsensitive <digit.sensitivee@gmail.com>
 * @copyright    2020 digitsensitive
 * @description  Dat.Gui Service
 *               dat.gui is a lightweight controller library for JavaScript.
 *               https://github.com/dataarts/dat.gui
 * @version      1.0.0
 * @license      {@link https://github.com/digitsensitive/phaser3-typescript/blob/master/LICENSE.md | MIT License}
 */
Object.defineProperty(exports, "__esModule", { value: true });
const dat = require("dat.gui");
class DatGuiService {
    constructor() {
        this.gui = new dat.GUI();
        this.controllers = [];
    }
    addFolder(folderName) {
        this.gui.addFolder(folderName);
    }
    addController(controllerName, target, propName, hasController, controllerFunction, items) {
        this.controllers.push(this.gui.add(target, propName, items).name(controllerName));
        if (hasController) {
            this.addOnChangeToController(this.controllers[this.controllers.length - 1], controllerFunction);
        }
    }
    addNumberController(controllerName, target, propName, hasController, configNumber, controllerFunction) {
        this.controllers.push(this.gui
            .add(target, propName, configNumber.min, configNumber.max, configNumber.step)
            .name(controllerName));
        if (hasController) {
            this.addOnChangeToController(this.controllers[this.controllers.length - 1], controllerFunction);
        }
    }
    addOnChangeToController(controller, onChangeFunction) {
        controller.onChange(onChangeFunction);
    }
}
exports.DatGuiService = DatGuiService;
