/**
 * @description astar-typescript finder class
 * @author Digitsensitive <digit.sensitivee@gmail.com>
 * @copyright 2017 - 2020 Digitsensitive
 * @license {@link https://opensource.org/licenses/MIT|MIT License}
 */
import { Grid } from '../core/grid';
import { IAStarFinderConstructor, IPoint } from '../interfaces/astar.interfaces';
import { Node } from '../core/node';
import { Heuristic } from '../types/astar.types';
export declare class AStarFinder {
    private grid;
    private closedList;
    private openList;
    readonly diagonalAllowed: boolean;
    private heuristicFunction;
    readonly includeStartNode: boolean;
    readonly includeEndNode: boolean;
    protected weight: number;
    constructor(aParams: IAStarFinderConstructor);
    findPath(startPosition: IPoint, endPosition: IPoint): number[][];
    /**
     * Set the heuristic to be used for pathfinding.
     * @param newHeuristic
     */
    setHeuristic(newHeuristic: Heuristic): void;
    /**
     * Get a copy/clone of the grid.
     */
    getGridClone(): Node[][];
    /**
     * Get the current grid
     */
    getGrid(): Grid;
}
